.. py:currentmodule:: drdmannturb

.. currentmodule:: drdmannturb.fluctuation_generation.sampling_methods



.. autoclass:: drdmannturb.Sampling_method_base
    :members:

.. autoclass:: drdmannturb.Sampling_method_freq
    :members:

.. autoclass:: drdmannturb.Sampling_FFT
    :members:

.. autoclass:: drdmannturb.Sampling_FFTW
    :members:

.. autoclass:: drdmannturb.Sampling_VF_FFTW
    :members:

.. autoclass:: drdmannturb.Sampling_DST
    :members:

.. autoclass:: drdmannturb.Sampling_DCT
    :members:



